==> mesa-22.2.4.tar.xz: mesa-22.2.4/src/gallium/auxiliary/util/u_file.h <==
/**************************************************************************
 *
 * Copyright 2009 VMware, Inc.
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sub license, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDERS, AUTHORS AND/OR ITS SUPPLIERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial portions
 * of the Software.
 *
 **************************************************************************/


#ifndef U_FILE_H_
#define U_FILE_H_

#if defined(PIPE_OS_UNIX)
#include <unistd.h>
#endif
#if defined(PIPE_OS_WINDOWS)
#include <io.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

static inline int
u_file_access(const char *path, int mode) {
#if defined(PIPE_OS_UNIX)
	return access(path, mode);
#elif defined(PIPE_OS_WINDOWS)
	return _access(path, mode);
#else
	return 0;
#endif
}

#ifdef __cplusplus
}
#endif

#endif /* U_FILE_H_ */

==> mesa-24.0.5.tar.xz: mesa-24.0.5/src/gallium/auxiliary/util/u_file.h <==
/**************************************************************************
 *
 * Copyright 2009 VMware, Inc.
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sub license, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDERS, AUTHORS AND/OR ITS SUPPLIERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial portions
 * of the Software.
 *
 **************************************************************************/


#ifndef U_FILE_H_
#define U_FILE_H_

#if DETECT_OS_UNIX
#include <unistd.h>
#endif
#if DETECT_OS_WINDOWS
#include <io.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

static inline int
u_file_access(const char *path, int mode) {
#if DETECT_OS_UNIX
	return access(path, mode);
#elif DETECT_OS_WINDOWS
	return _access(path, mode);
#else
	return 0;
#endif
}

#ifdef __cplusplus
}
#endif

#endif /* U_FILE_H_ */
